
# Type: variant to thing association_subject




URI: [biolink:variant_to_thing_association_subject](https://w3id.org/biolink/vocab/variant_to_thing_association_subject)


## Domain and Range

[VariantToThingAssociation](VariantToThingAssociation.md) ->  <sub>REQ</sub> [SequenceVariant](SequenceVariant.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [VariantToThingAssociation](VariantToThingAssociation.md)
